@@ -6,7 +6,7 @@ import torch
 from torch._utils import _accumulate
 import matplotlib.pyplot as plt
 import matplotlib as mpl
-from utils import femnist
+import femnist
 import os
 import pickle
 import datetime as d
